GpaResiduals(lands,gpa_coords)GpaResiduals mean center the aligned coordinates to get Procrustes residuals which are more appropriate for calculating covariance (McNulty 2009).
If generalized procrustes coordinates are not provided, the function will calculate them using data("aegla_landmarks")
result<-GpaResiduals(lands = aegla_landmarks)
#GPA consensus (matrix)
result$consens
#GPA consensus (vector)
result$cvectorized
#GPA residual matrix
result$residRun the code above in your browser using DataLab